==> plasma-sdo-1.1.7-sources.jar: org/plasma/text/lang3gl/java/SDOInterfaceNameResolver.java <==
/**
 *         PlasmaSDO™ License
 * 
 * This is a community release of PlasmaSDO™, a dual-license 
 * Service Data Object (SDO) 2.1 implementation. 
 * This particular copy of the software is released under the 
 * version 2 of the GNU General Public License. PlasmaSDO™ was developed by 
 * TerraMeta Software, Inc.
 * 
 * Copyright (c) 2013, TerraMeta Software, Inc. All rights reserved.
 * 
 * General License information can be found below.
 * 
 * This distribution may include materials developed by third
 * parties. For license and attribution notices for these
 * materials, please refer to the documentation that accompanies
 * this distribution (see the "Licenses for Third-Party Components"
 * appendix) or view the online documentation at 
 * <http://plasma-sdo.org/licenses/>.
 *  
 */
package org.plasma.text.lang3gl.java;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.plasma.config.Namespace;
import org.plasma.config.PlasmaConfig;
import org.plasma.provisioning.Class;
import org.plasma.provisioning.ClassRef;
import org.plasma.text.lang3gl.ClassNameResolver;

public class SDOInterfaceNameResolver extends DefaultNameResolver
    implements ClassNameResolver 
{
    private static Log log =LogFactory.getLog(
    		SDOInterfaceNameResolver.class); 

	@Override
	public String getName(Class clss) {		
		return replaceReservedCharacters(clss.getName());
	}
	
	@Override
	public String getQualifiedName(Class clss) {		
		Namespace sdoNamespace = PlasmaConfig.getInstance().getSDONamespaceByURI(clss.getUri());
		String packageName = sdoNamespace.getProvisioning().getPackageName();
		String qualifiedName = packageName + "." 
		    + replaceReservedCharacters(clss.getName()); 				
		
		return qualifiedName;
	}

	@Override
	public String getQualifiedName(ClassRef clssRef) {
		Namespace sdoNamespace = PlasmaConfig.getInstance().getSDONamespaceByURI(clssRef.getUri());
		String packageName = sdoNamespace.getProvisioning().getPackageName();
		String qualifiedName = packageName + "." 
		    + replaceReservedCharacters(clssRef.getName()); 				
		return qualifiedName;
	}


}

==> plasma-sdo-1.2.4-sources.jar: org/plasma/text/lang3gl/java/SDOInterfaceNameResolver.java <==
/**
 *         PlasmaSDO™ License
 * 
 * This is a community release of PlasmaSDO™, a dual-license 
 * Service Data Object (SDO) 2.1 implementation. 
 * This particular copy of the software is released under the 
 * version 2 of the GNU General Public License. PlasmaSDO™ was developed by 
 * TerraMeta Software, Inc.
 * 
 * Copyright (c) 2013, TerraMeta Software, Inc. All rights reserved.
 * 
 * General License information can be found below.
 * 
 * This distribution may include materials developed by third
 * parties. For license and attribution notices for these
 * materials, please refer to the documentation that accompanies
 * this distribution (see the "Licenses for Third-Party Components"
 * appendix) or view the online documentation at 
 * <http://plasma-sdo.org/licenses/>.
 *  
 */
package org.plasma.text.lang3gl.java;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.plasma.config.Namespace;
import org.plasma.config.PlasmaConfig;
import org.plasma.metamodel.Class;
import org.plasma.metamodel.ClassRef;
import org.plasma.metamodel.Package;
import org.plasma.text.lang3gl.ClassNameResolver;

public class SDOInterfaceNameResolver extends DefaultNameResolver
    implements ClassNameResolver 
{
    private static Log log =LogFactory.getLog(
    		SDOInterfaceNameResolver.class); 

	@Override
	public String getName(Class clss) {		
		return replaceReservedCharacters(clss.getName());
	}
	
	@Override
	public String getQualifiedName(Class clss, Package pkg) {		
		Namespace sdoNamespace = PlasmaConfig.getInstance().getSDONamespaceByURI(clss.getUri());
		String packageName = sdoNamespace.getProvisioning().getPackageName();
		String qualifiedName = packageName + "." 
		    + replaceReservedCharacters(clss.getName()); 				
		checkUnresolvableNameCollision(qualifiedName, clss, pkg);
		return qualifiedName;
	}

	@Override
	public String getQualifiedName(ClassRef clssRef) {
		Namespace sdoNamespace = PlasmaConfig.getInstance().getSDONamespaceByURI(clssRef.getUri());
		String packageName = sdoNamespace.getProvisioning().getPackageName();
		String qualifiedName = packageName + "." 
		    + replaceReservedCharacters(clssRef.getName()); 				
		return qualifiedName;
	}


}
